# tibetan_analysis
藏文词、句的相关的识别功能及其正字规范下的合法性判断功能
### 一、下载方式

* pypi ：  如果需要直接使用可从pypi下载   pip install tibetan-analysis
* github：如果需要修改源码可从 [github](https://github.com/puntsokCN/tibetan_analysis) 下载

### 二、文件结构

- analysis.py                 --    Word类、 Auxiliary_Word类 源码


### 三、Word 类

- front()  ----  			      得到前加字(སྔོན་འཇུག་)     若存在返回该字符；若不存在返回 None
- top()   ----                     得到上加字(མགོ་ཅན་)     若存在返回该字符；若不存在返回 None
- basic()  ----                   得到基字(མིང་གཞི་)     若存在返回该字符；若不存在返回 None
- below()  ----                  得到下加字(མདོགས་ཅན་)     若存在返回该字符；若不存在返回 None
- symbol() ----                 得到音标(དབྱངས་)     若存在返回该字符；若不存在返回 None
- behind()  ----                 得到后加字(རྗེས་འཇུག་)     若存在返回该字符；若不存在返回 None
- repeat_behind() ----     得到重后加字(ཡང་འཇུག་)     若存在返回该字符；若不存在返回 None
- get_all()                   
  1. 返回一个数组，其内容对应各个上述各个元素：[前加字，上加字，基字，下加字，音标，后加字， 又后加字]
  2. 数组内对应元素若存在存储着：对应藏文字符；若不存在存储着： None
  3. 以上获取各项元素的方法，实则是对该数组进行查询	
- is_right()             若该词在正字规范下存在，则返回合法的提示； 若不存在，则返回具体哪个元素出现异常的信息

### 四、Auxiliary_Word 类 

- analysis()  ----        若在句中存在非法的助词则返回正字合法的助词建议。可以根据需要调整源码
- 待添加     ---   根据其他助词相关需求，设计功能
  1.  输出格式设计 

      1)  sentence：在经过滤的藏文句子里标出程序判断的可疑项的序号  

      2)  advice：对应序号的合法性助词的建议

  2.  判错对象：  程序仅对 根据前项词的结构，严格遵守规则的助词类型有判定能力。无法判断根据语义使用的助词的合法性

  3. 结果： 程序根据规则对判断非法的助词生成合法助词的建议，其中有多选项需要使用者根据语义和其适用场景的定义去选择

  

### 五、使用示例   (.py文件)

```python
import tibetan_analysis as ta

######### 1.单词分析功能
# 从模块包的word文件中实例化 Word 类，藏文以参数形式传入
s = ta.Word("བསྒྲིགས")       

# 若存在元素，返回对应藏文字符； 若不存在返回 None
print("前加字(སྔོན་འཇུག་):    ", s.front())
print("上加字(མགོ་ཅན་):     ", s.top())
print("基字(མིང་གཞི་):       ", s.basic())
print("下加字(མདོགས་ཅན་):   ", s.below())
print("音标(དབྱངས་):        ", s.symbol())
print("后加字(རྗེས་འཇུག་):    ", s.behind())
print("重后加字(ཡང་འཇུག་):  ", s.repeat_behind())

# 1.得到一个元素数组：[前加字，上加字，基字，下加字，音标，后加字， 又后加字]
# 2.数组内对应元素若存在存储着：对应藏文字符；若不存在存储着： None
# 3.以上获取各项元素的方法，实则是对该数组进行查询
print("查看全部:         ", s.get_all())

# 若该词在正字规范下存在，则返回合法的提示； 若不存在，则返回具体哪个元素出现异常的信息
print(s.is_right())


#######  2.助词分析功能
# 输入的藏文句子不太过长，建议一行为单位传入
ss = '༣ ༂ ངས་བཀྲ་ཤིས་གིས་ཡང་དེ་དག་དུ་ ཀྱི་རོགས་རམ་གྲུབ་གིས་ཡང་རོགས་པ་ཀྱང་བྱེད་གྱི་འདུག་དམ་  བཟང་གོ་ ཚང་མ་ལེགས་རུ་ཕྱིན་སྟེ་ ལོ་རྩ་པ་  དག་ཞེས་གསུངས། ཞིང་བ་ ལྷ་ས་བ་'
# 从模块中实例化 Auxiliary_Word类 藏文句子以参数形式传入，一次传参句子不宜过长
aux_word = ta.Auxiliary_Word(ss)      

# 输出设计为 sentence：排除干扰项的子串里标出可疑项的序号   advice：对应序号的合法性助词的建议
print("\n\n", aux_word.analysis())

```

